==> react-image-annotate_ns_demo-4.0.70.tgz: package/Annotator/reducers/history-handler.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import moment from "moment";
import { setIn, updateIn, without } from "seamless-immutable";
import getActiveImage from "./get-active-image";
var typesToSaveWithHistory = {
  BEGIN_BOX_TRANSFORM: "Transform/Move Box",
  BEGIN_MOVE_POINT: "Move Point",
  DELETE_REGION: "Delete Region"
};
export var saveToHistory = function saveToHistory(state, name) {
  return updateIn(state, ["history"], function (h) {
    return [{
      time: moment().toDate(),
      state: without(state, "history"),
      name: name
    }].concat((h || []).slice(0, 9));
  });
};
export default (function (reducer) {
  return function (state, action) {
    var prevState = state;
    var nextState = reducer(state, action);

    if (action.type === "REDO_HISTORY") {
      var newArr = _toConsumableArray(window.annotation_redo) || [];

      if (newArr.length) {
        var lastElement = newArr[newArr.length - 1].annotation;
        newArr.splice(window.annotation_redo.length - 1, 1);
        window.annotation_redo = newArr;

        var _state = saveToHistory(nextState, lastElement.name);

        var _getActiveImage = getActiveImage(_state),
            pathToActiveImage = _getActiveImage.pathToActiveImage;

        return setIn(_state, [].concat(_toConsumableArray(pathToActiveImage), ["regions"]), lastElement.regionsArr);
      }
    }

    if (action.type === "RESTORE_HISTORY") {
      if (state.history.length > 0) {
        var history_return = function history_return() {
          console.log(nextState);
          var obj = {
            annotation: _objectSpread({}, nextState.history[0], {
              regionsArr: nextState.images[0].regions
            })
          };

          var newArr = _toConsumableArray(window.annotation_redo);

          newArr.push(obj); // let final = newArr.filter((item, index, self) => {
          //   if (
          //     index ===
          //     self.findIndex(
          //       (t) =>
          //         t?.annotation?.lastMouseMoveCall ===
          //         item?.annotation?.lastMouseMoveCall
          //     )
          //   ) {
          //     return item
          //   }
          // })

          window.annotation_redo = newArr;
          return setIn(nextState.history[0].state, ["history"], nextState.history.slice(1));
        };

        return history_return();
      }
    } else {
      if (prevState !== nextState && Object.keys(typesToSaveWithHistory).includes(action.type)) {
        return setIn(nextState, ["history"], [{
          time: moment().toDate(),
          state: without(prevState, "history"),
          name: typesToSaveWithHistory[action.type] || action.type
        }].concat(nextState.history || []).slice(0, 9));
      }
    }

    return nextState;
  };
});

==> react-image-annotate_ns_demo-5.0.11.tgz: package/Annotator/reducers/history-handler.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import moment from "moment";
import { setIn, updateIn, without } from "seamless-immutable";
import getActiveImage from "./get-active-image";
var typesToSaveWithHistory = {
  BEGIN_BOX_TRANSFORM: "Transform/Move Box",
  BEGIN_MOVE_POINT: "Move Point",
  DELETE_REGION: "Delete Region"
};
export var saveToHistory = function saveToHistory(state, name) {
  return updateIn(state, ["history"], function (h) {
    return [{
      time: moment().toDate(),
      state: without(state, "history"),
      name: name
    }].concat((h || []).slice(0, 9));
  });
};
export default (function (reducer) {
  return function (state, action) {
    var prevState = state;
    var nextState = reducer(state, action);

    if (action.type === "REDO_HISTORY") {
      var newArr = _toConsumableArray(window.annotation_redo) || [];

      if (newArr.length) {
        var lastElement = newArr[newArr.length - 1].annotation;
        newArr.splice(window.annotation_redo.length - 1, 1);
        window.annotation_redo = newArr;

        var _state = saveToHistory(nextState, lastElement.name);

        var _getActiveImage = getActiveImage(_state),
            pathToActiveImage = _getActiveImage.pathToActiveImage;

        return setIn(_state, [].concat(_toConsumableArray(pathToActiveImage), ["regions"]), lastElement.regionsArr);
      }
    }

    if (action.type === "RESTORE_HISTORY") {
      if (state.history.length > 0) {
        var history_return = function history_return() {
          var obj = {};

          if (nextState.annotationType === "video") {
            var _nextState$history, _nextState$keyframes, _nextState$keyframes$;

            obj = {
              annotation: _objectSpread({}, nextState === null || nextState === void 0 ? void 0 : (_nextState$history = nextState.history) === null || _nextState$history === void 0 ? void 0 : _nextState$history[0], {
                regionsArr: nextState === null || nextState === void 0 ? void 0 : (_nextState$keyframes = nextState.keyframes) === null || _nextState$keyframes === void 0 ? void 0 : (_nextState$keyframes$ = _nextState$keyframes[nextState.currentVideoTime]) === null || _nextState$keyframes$ === void 0 ? void 0 : _nextState$keyframes$.regions
              })
            };
          } else {
            var _nextState$history2, _nextState$images, _nextState$images$;

            obj = {
              annotation: _objectSpread({}, nextState === null || nextState === void 0 ? void 0 : (_nextState$history2 = nextState.history) === null || _nextState$history2 === void 0 ? void 0 : _nextState$history2[0], {
                regionsArr: nextState === null || nextState === void 0 ? void 0 : (_nextState$images = nextState.images) === null || _nextState$images === void 0 ? void 0 : (_nextState$images$ = _nextState$images[0]) === null || _nextState$images$ === void 0 ? void 0 : _nextState$images$.regions
              })
            };
          }

          var newArr = _toConsumableArray(window.annotation_redo);

          newArr.push(obj); // let final = newArr.filter((item, index, self) => {
          //   if (
          //     index ===
          //     self.findIndex(
          //       (t) =>
          //         t?.annotation?.lastMouseMoveCall ===
          //         item?.annotation?.lastMouseMoveCall
          //     )
          //   ) {
          //     return item
          //   }
          // })

          window.annotation_redo = newArr;
          return setIn(nextState.history[0].state, ["history"], nextState.history.slice(1));
        };

        return history_return();
      }
    } else {
      if (prevState !== nextState && Object.keys(typesToSaveWithHistory).includes(action.type)) {
        return setIn(nextState, ["history"], [{
          time: moment().toDate(),
          state: without(prevState, "history"),
          name: typesToSaveWithHistory[action.type] || action.type
        }].concat(nextState.history || []).slice(0, 9));
      }
    }

    return nextState;
  };
});
